@@ -12,14 +12,14 @@ from ..base.histo_dataset import HistoDataset
 
 def midog_classification_patches(
     root: str,  # '/data/ldap/histopathologic/original_read_only/MIDOG'
-    transformation = None,
-    pre_transformation = None,
+    transformation=None,
+    pre_transformation=None,
     subset: str = "all",
     splitting_seed: int = 69,
     splitting_trainings_percentage: float = 0.8,
     scanner_to_use: U[int, list] = None,
-    seed:int = None,
-    patch_size:int = None,
+    seed: int = None,
+    patch_size: int = None,
 ) -> HistoDataset:
     """
     Creates the MIDOG dataset and returns it as type HistoDataset, which inherits from torch.utils.data.Dataset.
@@ -35,7 +35,7 @@ def midog_classification_patches(
                        is called with a seed and will give always the same
                        result.
         subset: Which part of the dataset should be used.
-                One of {"train", "valid", "test", "all"}
+                One of {"train", "validation", "test", "all"}
         splitting_seed: Seed used for splitting the data set
         splitting_trainings_percentage: Percentage how to split data
         scanner_to_use: TODO
@@ -45,7 +45,7 @@ def midog_classification_patches(
                 set, the "transformation" will use always the same seed
                 depending on the call position.
         patch_size: TODO
-    
+
     Returns:
         HistoDataset:
             The dataset that loads the bach patches. You can use this
@@ -55,13 +55,15 @@ def midog_classification_patches(
     manipulators_to_use = []
 
     # handle training, validation and test cases
-    if subset == "train":
+    if subset:
+        subset = subset.lower()
+    if subset.startswith("tr"):
         manipulators_to_use.append(
             df_manipulators.RandomFilterByColumnValue(
                 "image_id", splitting_trainings_percentage, mode=0, seed=splitting_seed
             )
         )
-    elif subset == "valid":
+    elif subset.startswith("val"):
         manipulators_to_use.extend(
             [
                 df_manipulators.RandomFilterByColumnValue(
@@ -72,7 +74,7 @@ def midog_classification_patches(
                 ),
             ]
         )
-    elif subset == "test":
+    elif subset.startswith("te"):
         manipulators_to_use.extend(
             [
                 df_manipulators.RandomFilterByColumnValue(
@@ -87,7 +89,7 @@ def midog_classification_patches(
         pass
     else:
         raise NotImplementedError(
-            'The parameter "subset" needs to be one of ["train", "valid", "test", "all"].'
+            'The parameter "subset" needs to be one of ["train", "validation", "test", "all"].'
         )
 
     # handle scanner values
@@ -122,3 +124,65 @@ def midog_classification_patches(
         da_transfs=transformation,
     )
     return ds
+
+
+def midog_classification_patches_preprocessed(
+    root: str,  # '/data/ldap/histopathologic/original_read_only/MIDOG2/'
+    transformation: O[U[Callable, Sequence[Callable]]] = None,
+    pre_transformation: O[U[Callable, Sequence[Callable]]] = None,
+    subset: O[str] = "train",
+    seed: O[int] = None,
+) -> HistoDataset:
+    """
+    Creates the midog dataset and returns it as type HistoDataset, which inherits from torch.utils.data.Dataset.
+
+    Data and further information can be found at TODO
+
+    Arguments:
+        root: absolute path to the dataset files.
+                transformation (Callable): A callable or a list of
+                       callable transformations.
+        pre_transformation (Callable): A callable or a list of
+                       callable transformations. "pre_transformation"
+                       is called before "transformation". The transformation
+                       is called with a seed and will give always the same
+                       result.
+        subset: Which part of the dataset should be used.
+                One of {"train", "valid", "test"}
+        seed:   The seed that is used for the "pre_transformation" and the
+                "transformation". If the seed is set, the "pre_transformation"
+                will always use the same seed for a data row. If the seed is
+                set, the "transformation" will use always the same seed
+                depending on the call position.
+
+    Returns:
+        HistoDataset:
+            The dataset that loads the bach patches. You can use this
+            as normal pytorch dataset. If you call it, the data will
+            be returned as dictionary.
+    """
+    if subset:
+        subset = subset.lower()
+    if subset.startswith("tr"):
+        path_to_dataset = os.path.join(root, "train")
+    elif subset.startswith("val"):
+        path_to_dataset = os.path.join(root, "valid")
+    elif subset.startswith("test"):
+        path_to_dataset = os.path.join(root, "test")
+    else:
+        raise NotImplementedError(
+            'The parameter "subset" needs to be one of ["train", "valid", "test"].'
+        )
+
+    path_to_csv = os.path.join(path_to_dataset, "features.csv")
+    # create HistoDataset object and pass relevant attributes
+    ds = HistoDataset(
+        df_creators.CreateDFFromCSV(path_to_csv),
+        path_to_dataset,
+        data_readers="data/{id}.tiff",
+        feature_readers=data_readers.ReadValueFromCSV(r"{feature}", encoded_values=["0", "1"]),
+        seed=seed,
+        pre_transfs=pre_transformation,
+        da_transfs=transformation,
+    )
+    return ds
