@@ -11,10 +11,10 @@ from torchvision.transforms import Compose
 
 
 def pcam_patches(
-    root: str,
+    root: str, # '/data/ldap/histopathologic/original_read_only/PCAM_extracted'
     transformation: O[U[Callable, Sequence[Callable]]] = None,
     #   pre_transformation: O[U[Callable, Sequence[Callable]]] = None, # pretrans not possible yet
-    subset: O[str] = "train"
+    subset: O[str] = "train",
 ) -> Dataset:
     """
     Creates the PCAM dataset and returns it as type HistoDataset, which inherits from torch.utils.data.Dataset.
@@ -25,34 +25,47 @@ def pcam_patches(
         root: Absolute path to the dataset files.
         transformation: A callable or a list of callable transformations.
         subset: Which part of the dataset should be used.
-                One of {"train", "valid", "test"}
-    
+                One of {"train", "validation", "test"}
+
     Returns:
         torch.utils.data.Dataset:
             The dataset that loads the pcam patches. You can use this
             as normal pytorch dataset. If you call it, the data will
-            be returned as dictionary with structure:            
+            be returned as dictionary with structure:
             dict['images': torch.Tensor, 'labels': torch.Tensor].
     """
-
-    if subset == 'train':
-        imgs_hdf5_filepath = root + '/camelyonpatch_level_2_split_train_x.h5'
-        labels_hdf5_filepath = root + '/camelyonpatch_level_2_split_train_y.h5'
-        return PCAM(imgs_hdf5_filepath=imgs_hdf5_filepath, labels_hdf5_filepath=labels_hdf5_filepath, transform=transformation)
-    elif subset == 'eval':
-        imgs_hdf5_filepath = root + '/camelyonpatch_level_2_split_valid_x.h5'
-        labels_hdf5_filepath = root + '/camelyonpatch_level_2_split_test_y.h5'
-        return PCAM(imgs_hdf5_filepath=imgs_hdf5_filepath, labels_hdf5_filepath=labels_hdf5_filepath, transform=transformation)
-    elif subset == 'test':
-        imgs_hdf5_filepath = root + '/camelyonpatch_level_2_split_valid_x.h5'
-        labels_hdf5_filepath = root + '/camelyonpatch_level_2_split_test_y.h5'
-        return PCAM(imgs_hdf5_filepath=imgs_hdf5_filepath, labels_hdf5_filepath=labels_hdf5_filepath, transform=transformation)
+    if subset:
+        subset = subset.lower()
+    if subset.startswith("tr"):
+        imgs_hdf5_filepath = root + "/camelyonpatch_level_2_split_train_x.h5"
+        labels_hdf5_filepath = root + "/camelyonpatch_level_2_split_train_y.h5"
+        return PCAM(
+            imgs_hdf5_filepath=imgs_hdf5_filepath,
+            labels_hdf5_filepath=labels_hdf5_filepath,
+            transform=transformation,
+        )
+    elif subset.startswith("val"):
+        imgs_hdf5_filepath = root + "/camelyonpatch_level_2_split_valid_x.h5"
+        labels_hdf5_filepath = root + "/camelyonpatch_level_2_split_test_y.h5"
+        return PCAM(
+            imgs_hdf5_filepath=imgs_hdf5_filepath,
+            labels_hdf5_filepath=labels_hdf5_filepath,
+            transform=transformation,
+        )
+    elif subset.startswith("te"):
+        imgs_hdf5_filepath = root + "/camelyonpatch_level_2_split_valid_x.h5"
+        labels_hdf5_filepath = root + "/camelyonpatch_level_2_split_test_y.h5"
+        return PCAM(
+            imgs_hdf5_filepath=imgs_hdf5_filepath,
+            labels_hdf5_filepath=labels_hdf5_filepath,
+            transform=transformation,
+        )
     # TODO use case not possible yet
     # elif subset == 'all':
     #     pass
     else:
         raise NotImplementedError(
-            'The parameter "subset" needs to be one of ["train", "valid", "test", "all"].'
+            'The parameter "subset" needs to be one of ["train", "validation", "test"].'
         )
 
 
@@ -63,7 +76,14 @@ class PCAM(Dataset):
     Data and further information can be found at https://humanunsupervised.github.io/humanunsupervised.com/pcam/pcam-cancer-detection.html
     """
 
-    def __init__(self, imgs_hdf5_filepath: str, labels_hdf5_filepath: str, imgs_key: str = 'x', labels_key: str = 'y', transform: O[Compose] = None):
+    def __init__(
+        self,
+        imgs_hdf5_filepath: str,
+        labels_hdf5_filepath: str,
+        imgs_key: str = "x",
+        labels_key: str = "y",
+        transform: O[Compose] = None,
+    ):
         """
         Initializes dataset.
         """
@@ -79,7 +99,7 @@ class PCAM(Dataset):
         """
         Returns length of dataset
         """
-        with File(self.labels_hdf5_filepath, 'r') as db:
+        with File(self.labels_hdf5_filepath, "r") as db:
             lens = len(db[self.labels_key])
 
         return lens
@@ -88,16 +108,16 @@ class PCAM(Dataset):
         """
         TODO
         """
-        
+
         # get images
-        with File(self.imgs_hdf5_filepath, 'r') as db:
-            image = (db[self.imgs_key][idx])
+        with File(self.imgs_hdf5_filepath, "r") as db:
+            image = db[self.imgs_key][idx]
         # get labels
-        with File(self.labels_hdf5_filepath, 'r') as db:
+        with File(self.labels_hdf5_filepath, "r") as db:
             label = db[self.labels_key][idx][0][0][0]  # TODO make it nice
 
         # transform data
         if self.transform:
             image = self.transform(image)
 
-        return {'image': image, 'label': label}
+        return {"data": image, "feature": label}
